{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
    La structure des decks hatebear est particulière et permet de lutter contre
    les decks contrôle et les decks combo en taxant l'adversaire sur la
    majorité des actions de jeu qui sont requises pour gagner la partie. La
    posture d'Ojutai dans ce matchup le met en difficulté. Au final, c'est en
    faveur de Livio-Prava grâce au swap Thalia, Guardian of Thraben.
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Midas" %}
{% set joueur2 = "Imperia86" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/rLXT5i6H5KI" %}
{% set date = "18 janvier 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.midas() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/livioprava", "img/split-crop/livio-prava.jpg") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/dragonlord-ojutai") }}{% endblock %}
{% block pilote2 %}{{ pilote.imperia86() }}{% endblock %}
