{% extends "decks/_layout_decks.html" %}

### PRESENTATION ###
{% block first_paragraph %}
    Il s'agit d'un deck qui cherche à prendre le contrôle de la partie puis de
    reconfigurer la Puce sur une créature pour avoir accès à davantage de cartes
    à chaque tour.
{% endblock %}
{% block second_paragraph %}
    La structure du deck se veut contrôlisante avec des moyens de filtrer le
    dessus du deck. En effet, cela permet de se garantir l'utilisation la plus
    optimale possible du général.
{% endblock %}
{% block third_paragraph %}
{% endblock %}


### LISTES ###
{% block lien %}
https://www.moxfield.com/decks/f5VWoDcDZEG1nx9kH7tJug{% endblock %}


### MATCHS ###
{% block matchs %}
{{ match.card2("/matchs/23-karlov-vs-reality-chip", "La puce et le fantôme cherchent à contrôler la réalité. Lequel des deux aura le dernier mot ?") }}
{% endblock %}


### PILOTES ###
{% block pilotes %}
<div class="row py-3 d-flex flex-wrap justify-content-around">
    <div class="col-sm-4">
        {{ pilote.aliquanto(played_on="31 mai 2022") }}
    </div>
</div>
{% endblock %}
