{% extends "matchs/_layout_matchs.html" %}

### PRESENTATION ###
{% block analyse %}
{% endblock %}


### JOUEURS ###
{% set joueur1 = "Aliquanto" %}
{% set joueur2 = "Domino" %}

### VIDEO ###
{% set youtube = "https://www.youtube.com/embed/cpmdbVL5mAs" %}
{% set date = "14 juin 2022" %}

### LEGENDE ###
{% block pilote1 %}{{ pilote.aliquanto() }}{% endblock %}
{% block deck1 %}{{ deck.card("/decks/elminster") }}{% endblock %}
{% block deck2 %}{{ deck.card("/decks/wilson-refined-grizzly", "img/split-crop/wilson, refined grizzly.jpg") }}{% endblock %}
{% block pilote2 %}{{ pilote.domino() }}{% endblock %}
