/****************
 * TETE DE PAGE *
 **************** */
.header a {
    text-decoration: none;
    color: $text-body;
}

/* Container holding the image and the text */
.banner_container {
    position: relative;
    text-align: center;
    color: black;
}
/* Centered text */
.centered {
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
}
