/*****************
 * POLICE DEDIÉE *
 ***************** */
@font-face {
    font-family: "FontAwesome";
    font-weight: 900;
    src: url("/static/fonts/fa-solid-900.ttf") format("truetype"),
        url("/static/fonts/fa-solid-900.svg") format("svg"),
        url("/static/fonts/fa-solid-900.woff") format("woff"),
        url("/static/fonts/fa-solid-900.woff2") format("woff2"),
        url("/static/fonts/fa-solid-900.eot") format("embedded-opentype");
    font-display: swap;
}

@font-face {
    font-family: "FontAwesome Brand";
    font-weight: 400;
    src: url("/static/fonts/fa-brands-400.ttf") format("truetype"),
        url("/static/fonts/fa-brands-400.svg") format("svg"),
        url("/static/fonts/fa-brands-400.woff") format("woff"),
        url("/static/fonts/fa-brands-400.woff2") format("woff2"),
        url("/static/fonts/fa-brands-400.eot") format("embedded-opentype");
    font-display: swap;
}
