/* ============ desktop view ============ */
@media all and (min-width: 768px) {
    .dropdown-menu li {
        position: relative;
    }
    .dropdown-menu .submenu{
        display: none;
        position: absolute;
        left: 100%;
        top: -7px;
    }
    .dropdown-menu .submenu-left{
        right: 100%;
        left: auto;
    }

    .dropdown-menu > li:hover,
    .dropdown-menu > li:focus,
    .dropdown-menu > li:active {
        background-color: #f1f1f1;
    }
    .dropdown-menu > li:hover > .submenu,
    .dropdown-menu > li:focus > .submenu,
    .dropdown-menu > li:active > .submenu {
        display: block;
    }
}
/* ============ desktop view .end// ============ */

/* ============ small devices ============ */
@media (max-width: 767px) {
    .dropdown-menu .dropdown-menu{
        margin-left:   0.7rem;
        margin-right:  0.7rem;
        margin-bottom: 0.5rem;
    }

}
/* ============ small devices .end// ============ */
